@@ -4,6 +4,8 @@ pub struct Stack {
     mem: *mut [u8]
 }
 
+unsafe impl Send for Stack {}
+
 impl Stack {
     pub fn new(stack_size: usize) -> Stack {
         // Allocate one more page as the guard page
@@ -20,6 +22,10 @@ impl Stack {
         let mem = unsafe { &mut *self.mem };
         &mut mem[0] as *mut u8 as usize + mem.len()
     }
+
+    pub fn get_mem(&self) -> *mut [u8] {
+        self.mem
+    }
 }
 
 impl Drop for Stack {
